require 'spec_helper'

describe BaselineResource do
  describe ".replace_with" do
    before :each do
      @report = Report.create_from_yaml(File.read(File.join(File.dirname(__FILE__), '../fixtures/reports/inspect.yaml')))
      @baseline = Baseline.create_from_report!(@report)

      @sudoers = @report.resource_statuses.find_by_title "/etc/sudoers"
      @sudoers.should be
    end

    it "should raise if given something that isn't a resource" do
      hosts = @baseline.resources.find_by_title("/etc/hosts")
      hosts.should be

      lambda {
        @baseline.resources.find_by_title("/etc/hosts").replace_with hosts
      }.should raise_error RuntimeError, /Expected a ResourceStatus, but got/
    end

    it "should replace one resource with another" do
      @baseline.resources.find_all_by_title("/etc/sudoers").map &:destroy
      @baseline.resources.find_all_by_title("/etc/hosts").count.should == 1

      @baseline.resources.find_by_title("/etc/hosts").replace_with @sudoers

      @baseline.resources.find_all_by_title("/etc/sudoers").count.should == 1
      @baseline.resources.find_all_by_title("/etc/hosts").count.should == 0
    end

    it "should fail if replacing a resource duplicates an existing resource" do
      @baseline.resources.find_all_by_title("/etc/sudoers").count.should == 1
      @baseline.resources.find_all_by_title("/etc/hosts").count.should == 1

      lambda {
        @baseline.resources.find_by_title("/etc/hosts").replace_with @sudoers
      }.should raise_error(ActiveRecord::RecordInvalid,
                           /File\[\/etc\/sudoers\] already exists/)
    end
  end
end
